Struct WpContentTypeV1
pub struct WpContentTypeV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
content type object for a surface
The content type object allows the compositor to optimize for the kind of content shown on the surface. A compositor may for example use it to set relevant drm properties like “content type”.
The client may request to switch to another content type at any time. When the associated surface gets destroyed, this object becomes inert and the client should destroy it.
See also the Request enum for this interface.